@@ -12,7 +12,7 @@ $tr->set_key($key);
 # I do not like it because It does not detect the right lan sometimes, 
 # but do not follow my idea and try to be 'Diligent' (James Axl).
 
-$tr->set_hint([qw{en ru ar tr});
+$tr->set_hint([qw{en ru ar tr}]);
 
 $tr->set_text('Hello');
 print $tr->detect_lang(), "\n";
