@@ -3,7 +3,7 @@ use Yandex::Translate;
 
 my $tr =  Yandex::Translate->new;
 
-my $key = 'trnsl.1.1.20170502T185327Z.003373b7b88cddda.5420c79cd704be7b9538b3e7d9ea9e7db457a4e7';
+my $key = 'yandex_key'; 
 
 $tr->set_key($key);
 
